pub struct GetNotificationSchemeForProjectParams {
pub project_key_or_id: String,
pub expand: Option<String>,
}Expand description
struct for passing parameters to the method get_notification_scheme_for_project
Fields
project_key_or_id: StringThe project ID or project key (case sensitive).
expand: Option<String>Use expand to include additional information in the response. This parameter accepts a comma-separated list. Expand options include: * all Returns all expandable information. * field Returns information about any custom fields assigned to receive an event. * group Returns information about any groups assigned to receive an event. * notificationSchemeEvents Returns a list of event associations. This list is returned for all expandable information. * projectRole Returns information about any project roles assigned to receive an event. * user Returns information about any users assigned to receive an event.